import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Double-buffered version of AquariumTest. Use this class to verify the basic
 * functionality of your program.
 * 
 * @author Johannes Liem
 *
 */
public class AquariumSimulation {
	private final int DELAY = 20;
	private Aquarium aquarium;
	// Can't use polymorphism by inheritance if you add a crab
	// Instead implement polymorhism using the interface class AquariumObject
  // private Fish[] fish;-- has been replaced
	private AquariumObject[] living;
	private Graphics g;
	private Timer timer;
	private int count = 0;

	private Graphics graphicsBuffer;
	private Image imgBuffer;

	public static void main(String[] args) {
		AquariumSimulation at = new AquariumSimulation();
		at.start();
	}

	public void start() {
		int[] x = {0, 30, 40, 50, 60, 70, 90, 100, 115,
				130, 115, 100, 90, 70, 60, 50, 40, 30, 0, 15};
		int[] y = {5, 15, 10, 7, 0, 7, 12, 15, 22, 25, 28, 35, 40,
				43, 50, 43, 40, 35, 45, 25};

		aquarium = new Aquarium(800,600);
		g = aquarium.getGraphicsContext();

		// Create image buffer
		Dimension d = aquarium.getSize();
		imgBuffer = aquarium.createImage(d.width, d.height);
		graphicsBuffer = imgBuffer.getGraphics();
		
		Sand s = new Sand(400,600,800);
		aquarium.addObject(s);

		Aerator a = new Aerator(700, 550, 550);
		aquarium.addObject(a);
		
		UnderwaterPlant p=new UnderwaterPlant(200,590,100,100);
		aquarium.addObject(p);
		 
	 	UnderwaterPlant p1=new UnderwaterPlant(400,590,50,300);
	 	aquarium.addObject(p1);
		 
	 UnderwaterPlant p2=new UnderwaterPlant(500,590,50,200);
		 aquarium.addObject(p2);

		aquarium.refresh(g);

		
		Polygon poly = new Polygon(x, y, x.length);
      living = new AquariumObject[8];
      living[0] = new Fish(280, 120);
      living[1] = new Fish(new Color(234,200,167), poly, 560, 400);
      living[2] = new MovingFish(315, 567);
      ((MovingFish)living[2]).setBounds(0,0,800,600);
     	living[3] = new MovingFish(new Color(214,30,230), poly, 700, 120);
    	((MovingFish)living[3]).setBounds(0,0,800,600);
		living[4] = new MovingFish(Color.black, poly, 500, 200);
    	((MovingFish)living[4]).setBounds(100,100,700,500);
		living[5] = new MovingFish(Color.orange, poly, 700, 120);
    	((MovingFish)living[5]).setBounds(100,100,700,500);
		living[6] = new Crab(150,590);
		living[7] = new Crab(600,590);

		timer = new Timer(DELAY, new AnimListener());
		timer.start();
	}

	public void nextFrame() {       
		// Draw onto the buffer
		aquarium.refresh(graphicsBuffer);

		for (int i=0; i<living.length; i++)
			living[i].paint(graphicsBuffer);

		// Transfer buffer to actual window
		g.drawImage(imgBuffer, 0, 0, aquarium);
	}

	private class AnimListener implements ActionListener {

		public void actionPerformed(ActionEvent ae) {
			nextFrame();

			count++;
			if (count == 2000) 
				timer.stop();
		}
	}
}
