import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Double-buffered version of AquariumTest. Use this class to verify the basic
 * functionality of your program.
 * 
 * @author Johannes Liem
 *
 */
public class AquariumTest {
	private final int DELAY = 20;
	private Aquarium aquarium;
	private Fish[] fish;
	private Graphics g;
	private Timer timer;
	private int count = 0;

	private Graphics graphicsBuffer;
	private Image imgBuffer;

	public static void main(String[] args) {
		AquariumTest at = new AquariumTest();
		at.start();
	}

	public void start() {
		int[] x = {0, 30, 40, 50, 60, 70, 90, 100, 115,
				130, 115, 100, 90, 70, 60, 50, 40, 30, 0, 15};
		int[] y = {5, 15, 10, 7, 0, 7, 12, 15, 22, 25, 28, 35, 40,
				43, 50, 43, 40, 35, 45, 25};

		aquarium = new Aquarium(800,600);
		g = aquarium.getGraphicsContext();

		// Create image buffer
		Dimension d = aquarium.getSize();
		imgBuffer = aquarium.createImage(d.width, d.height);
		graphicsBuffer = imgBuffer.getGraphics();
		
		Sand s = new Sand(400,600,800);
		aquarium.addObject(s);

		Aerator a = new Aerator(700, 550, 550);
		aquarium.addObject(a);

		aquarium.refresh(g);

		Polygon poly = new Polygon(x, y, x.length);
		fish = new Fish[4];
		fish[0] = new Fish(280, 120);
		fish[1] = new Fish(new Color(234,200,167), poly, 560, 400);
		fish[2] = new MovingFish(315, 500);
		((MovingFish)fish[2]).setBounds(0,0,800,600);
		fish[3] = new MovingFish(new Color(214,30,230), poly, 500, 120);
		((MovingFish)fish[3]).setBounds(0,0,800,600);

		timer = new Timer(DELAY, new AnimListener());
		timer.start();
	}

	public void nextFrame() {       
		// Draw onto the buffer
		aquarium.refresh(graphicsBuffer);

		for (int i=0; i<fish.length; i++)
			fish[i].paint(graphicsBuffer);

		// Transfer buffer to actual window
		g.drawImage(imgBuffer, 0, 0, aquarium);
	}

	private class AnimListener implements ActionListener {

		public void actionPerformed(ActionEvent ae) {
			nextFrame();

			count++;
			if (count == 1000) 
				timer.stop();
		}
	}
}
