//********************************************************************
//MovingFish.java       Author: Carlos Rios
//
// Collaboration Statement: I worked alone, using various internet sources
//********************************************************************

import java.awt.*;
import javax.swing.*;

/**
* Implements a graphical image of an fish that can be placed in an  aquarium.
* The fish moves within the aquarium inside a rectangular boundary.
* It can paint fish of different colors.
* It can draw fish of different shapes or it can draw a default fish shape.
* @author Carlos Rios
* @version 1.0
*/

public class MovingFish extends Fish implements AquariumObject 
{	
			//Inherited
			//Color fishColor;
			//Polygon fishPolygon;
			//int xFish, yFish;
			/** a polygon representing  the fish facing (pointing) left, the default fish faces right */
			Polygon reflectedFishPolygon;
			/** the minimum value of the x co-ordinate of a swimming fish */
			int fishMinx;
			/** the minimum value of the y co-ordinate of a swimming fish */
			int fishMiny;
			/** the maximum value of the x co-ordinate of a swimming fish */
			int fishMaxx;
			/** the maximum value of the x co-ordinate of a swimming fish */
			int fishMaxy;
			/** the maximum value of the y co-ordinate of a swimming fish */
			private int deltax=1;
			/** the movement of the fish in the positive x direction each time the fish is painted */
			private int deltay=1;
			/** the movement of the fish in the positive y direction each time the fish is painted */

			
			
	/**
	 *	 Creates an instance of a MovingFish.
	 * @param c The color of the Fish
	 * @param p The polygon representing the shape of the fish
	 * @param x The x coordinate of the initial location of the Fish
	 * @param y The y coordinate of the initial location of the Fish
	 */
   public MovingFish(Color c, Polygon p, int x, int y)  // Use the
         // specified polygon as the fish outline.  The coords are
         // relative to the x,y.  Make it the given solid color.
			{
			super(c,p,x,y);
			int[] reflect = new int[fishPolygon.xpoints.length];
			 
			 for(int i=0;i<fishPolygon.xpoints.length;i++)
			 {
			 reflect[i]=2*xFish-fishPolygon.xpoints[i];

			 }
			 
			 reflectedFishPolygon=new Polygon(reflect,fishPolygon.ypoints,fishPolygon.xpoints.length);
			 int xtranslate = reflectedFishPolygon.getBounds().width;
			 reflectedFishPolygon.translate(xtranslate,0);		 			 
			}
			
	/**
	 *	Creates an instance of a an MovingFish.Uses the default shape and color.
	 * @param x The x coordinate of the initial location of the Fish
	 * @param y The y coordinate of the initial location of the Fish
	 */
			
   public MovingFish(int x, int y)   // Create some random (but decent)
         // looking fish at the given position
			{
			super(x,y);
			int[] reflect = new int[fishPolygon.xpoints.length];
			 
			 for(int i=0;i<fishPolygon.xpoints.length;i++)
			 {
			 reflect[i]=2*xFish-fishPolygon.xpoints[i];

			 }
			 
			 reflectedFishPolygon=new Polygon(reflect,fishPolygon.ypoints,fishPolygon.xpoints.length);
			 int xtranslate = reflectedFishPolygon.getBounds().width;
			 reflectedFishPolygon.translate(xtranslate,0);		
			
			}
			
	/**
	 *	 Sets the boundaries for the swimming fish
	 * @param minx The minimum value of the x co-ordinate of a swimming fish.
	 * @param miny The minimum value of the y co-ordinate of a swimming fish.
	 * @param maxx The maximum value of the x co-ordinate of a swimming fish.
	 * @param maxy The maximum value of the y co-ordinate of a swimming fish
	 */
   public void setBounds(int minx, int miny, int maxx, int maxy)  // Defines
         // the boundaries for swimming
			{
		 		fishMinx=minx;
		 		fishMiny=miny;
		 		fishMaxx=maxx;
			 	fishMaxy=maxy;
			
			}
			
	/**
	 *	 Paints the Fish .
	 *  Before each iteration of painting the position is changed
	 * @param g The graphics context for painting.
	 */
   public void paint(Graphics g)  
	 // Draw the fish
	 {	
	 	xFish+=deltax;
		yFish+=deltay;
	 	
	 	if(xFish<fishMinx || xFish>fishMaxx) 
			{
			deltax=deltax*-1;
			}
		if(yFish<fishMiny || yFish>fishMaxy) 
			{
			deltay=deltay*-1;
			}
	 
	 	fishPolygon.translate(deltax,deltay);
		reflectedFishPolygon.translate(deltax,deltay);
	   g.setColor(fishColor);
		if(deltax>0)
  		g.fillPolygon(fishPolygon);
		else
		g.fillPolygon(reflectedFishPolygon);
	 
	 }
}

